==> snpMatrix_1.6.1.tgz: snpMatrix/doc/imputation-vignette.R <==
###################################################
### chunk number 1: init
###################################################
library(snpMatrix)
library(hexbin)
data(for.exercise)


###################################################
### chunk number 2: select
###################################################
sel <- seq(1, ncol(snps.10),2) 
missing <- snps.10[,sel]
present <- snps.10[,-sel] 
missing 
present 


###################################################
### chunk number 3: positions
###################################################
pos.miss <- snp.support$position[sel]
pos.pres <- snp.support$position[-sel]


###################################################
### chunk number 4: rules
###################################################
rules <- snp.imputation(present, missing, pos.pres, pos.miss)


###################################################
### chunk number 5: rule1
###################################################
rules[1]


###################################################
### chunk number 6: summary
###################################################
summary(rules)


###################################################
### chunk number 7: ruleplot
###################################################
plot(rules)


###################################################
### chunk number 8: imptest
###################################################
imp <- single.snp.tests(cc, stratum, data=subject.support,
                        snp.data=present, rules=rules)


###################################################
### chunk number 9: realtest
###################################################
obs <- single.snp.tests(cc, stratum, data=subject.support, snp.data=missing)


###################################################
### chunk number 10: compare
###################################################
logP.imp <- -log10(p.value(imp, df=1))
logP.obs <- -log10(p.value(obs, df=1))
hb <- hexbin(logP.obs, logP.imp, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 11: best
###################################################
use <- imputation.r2(rules)>0.9
hb <- hexbin(logP.obs[use], logP.imp[use], xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 12: rsqmaf
###################################################
hb <- hexbin(imputation.maf(rules), imputation.r2(rules), xbin=50)
sp <- plot(hb)


###################################################
### chunk number 13: imptest-rhs
###################################################
imp2 <- snp.rhs.tests(cc~strata(stratum), family="binomial", 
                      data=subject.support, snp.data=present, rules=rules)
logP.imp2 <- -log10(p.value(imp2))
hb <- hexbin(logP.obs, logP.imp2, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 14: class-imp-obs
###################################################
class(imp)
class(obs)


###################################################
### chunk number 15: save-scores
###################################################
obs <- single.snp.tests(cc, stratum, data=subject.support, snp.data=missing, 
                        score=TRUE)
imp <- single.snp.tests(cc, stratum, data=subject.support,
                        snp.data=present, rules=rules, score=TRUE)
class(obs)
class(imp)


###################################################
### chunk number 16: pool
###################################################
both <- pool(obs, imp)
class(both)
both[1:5]


###################################################
### chunk number 17: pool-score
###################################################
both <- pool(obs, imp, score=TRUE)
class(both)


###################################################
### chunk number 18: sign
###################################################
table(effect.sign(obs))


###################################################
### chunk number 19: switch
###################################################
effect.sign(obs)[1:6]
sw.obs <- switch.alleles(obs, c("rs12773042", "rs10904596"))
class(sw.obs)
effect.sign(sw.obs)[1:6]

==> snpMatrix_1.10.3.tgz: snpMatrix/doc/imputation-vignette.R <==
###################################################
### chunk number 1: init
###################################################
library(snpMatrix)
library(hexbin)
data(for.exercise)


###################################################
### chunk number 2: select
###################################################
training <- sample(1000, 200)
in.target<- seq(1, ncol(snps.10),2) 
missing <- snps.10[training, -in.target]
present <- snps.10[training, in.target] 
missing 
present 


###################################################
### chunk number 3: target
###################################################
target <- snps.10[-training, in.target]
target


###################################################
### chunk number 4: 
###################################################
lost <- snps.10[-training, -in.target]
lost


###################################################
### chunk number 5: positions
###################################################
pos.miss <- snp.support$position[-in.target]
pos.pres <- snp.support$position[in.target]


###################################################
### chunk number 6: rules
###################################################
rules <- snp.imputation(present, missing, pos.pres, pos.miss)


###################################################
### chunk number 7: rule1
###################################################
rules[1:10]


###################################################
### chunk number 8: summary
###################################################
summary(rules)


###################################################
### chunk number 9: ruleplot
###################################################
plot(rules)


###################################################
### chunk number 10: imptest
###################################################
imp <- single.snp.tests(cc, stratum, data=subject.support,
                        snp.data=target, rules=rules)


###################################################
### chunk number 11: realtest
###################################################
obs <- single.snp.tests(cc, stratum, data=subject.support, snp.data=lost)


###################################################
### chunk number 12: compare
###################################################
logP.imp <- -log10(p.value(imp, df=1))
logP.obs <- -log10(p.value(obs, df=1))
hb <- hexbin(logP.obs, logP.imp, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 13: best
###################################################
use <- imputation.r2(rules)>0.9
hb <- hexbin(logP.obs[use], logP.imp[use], xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 14: rsqmaf
###################################################
hb <- hexbin(imputation.maf(rules), imputation.r2(rules), xbin=50)
sp <- plot(hb)


###################################################
### chunk number 15: imptest-rhs
###################################################
imp2 <- snp.rhs.tests(cc~strata(stratum), family="binomial", 
                      data=subject.support, snp.data=target, rules=rules)
logP.imp2 <- -log10(p.value(imp2))
hb <- hexbin(logP.obs, logP.imp2, xbin=50)
sp <- plot(hb)
hexVP.abline(sp$plot.vp, 0, 1, col="black")


###################################################
### chunk number 16: class-imp-obs
###################################################
class(imp)


###################################################
### chunk number 17: save-scores
###################################################
obs <- single.snp.tests(cc, stratum, data=subject.support, snp.data=missing, 
                        score=TRUE)
imp <- single.snp.tests(cc, stratum, data=subject.support,
                        snp.data=target, rules=rules, score=TRUE)


###################################################
### chunk number 18: 
###################################################
class(obs)
class(imp)


###################################################
### chunk number 19: pool
###################################################
both <- pool(obs, imp)
class(both)
both[1:5]


###################################################
### chunk number 20: pool-score
###################################################
both <- pool(obs, imp, score=TRUE)
class(both)


###################################################
### chunk number 21: sign
###################################################
table(effect.sign(obs))


###################################################
### chunk number 22: switch
###################################################
effect.sign(obs)[1:6]
sw.obs <- switch.alleles(obs, c("rs7093061", "rs7475011"))
class(sw.obs)
effect.sign(sw.obs)[1:6]
